% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/docx_add.R
\name{body_add}
\alias{body_add}
\alias{body_add.character}
\alias{body_add.numeric}
\alias{body_add.factor}
\alias{body_add.fpar}
\alias{body_add.data.frame}
\alias{body_add.block_caption}
\alias{body_add.block_list}
\alias{body_add.block_toc}
\alias{body_add.external_img}
\alias{body_add.run_pagebreak}
\alias{body_add.run_columnbreak}
\alias{body_add.gg}
\alias{body_add.plot_instr}
\title{add content into a Word document}
\usage{
body_add(x, value, ...)

\method{body_add}{character}(x, value, style = NULL, ...)

\method{body_add}{numeric}(x, value, style = NULL, format_fun = formatC, ...)

\method{body_add}{factor}(x, value, style = NULL, format_fun = as.character, ...)

\method{body_add}{fpar}(x, value, style = NULL, ...)

\method{body_add}{data.frame}(
  x,
  value,
  style = NULL,
  header = TRUE,
  first_row = TRUE,
  first_column = FALSE,
  last_row = FALSE,
  last_column = FALSE,
  no_hband = FALSE,
  no_vband = TRUE,
  ...
)

\method{body_add}{block_caption}(x, value, ...)

\method{body_add}{block_list}(x, value, ...)

\method{body_add}{block_toc}(x, value, ...)

\method{body_add}{external_img}(x, value, style = "Normal", ...)

\method{body_add}{run_pagebreak}(x, value, style = NULL, ...)

\method{body_add}{run_columnbreak}(x, value, style = NULL, ...)

\method{body_add}{gg}(x, value, width = 6, height = 5, res = 300, style = "Normal", ...)

\method{body_add}{plot_instr}(x, value, width = 6, height = 5, res = 300, style = "Normal", ...)
}
\arguments{
\item{x}{an rdocx object}

\item{value}{object to add in the document. Supported objects
are vectors, data.frame, graphics, block of formatted paragraphs,
unordered list of formatted paragraphs,
pretty tables with package flextable, 'Microsoft' charts with package mschart.}

\item{...}{further arguments passed to or from other methods. When
adding a \code{ggplot} object or \code{plot_instr}, these arguments will be used
by png function.}

\item{style}{paragraph style name. These names are available with function \link{styles_info}
and are the names of the Word styles defined in the base document (see
argument \code{path} from \link{read_docx}).}

\item{format_fun}{a function to be used to format values.}

\item{header}{display header if TRUE}

\item{first_row}{Specifies that the first column conditional formatting should be
applied.}

\item{first_column}{Specifies that the first column conditional formatting should
be applied.}

\item{last_row}{Specifies that the first column conditional formatting should be applied.}

\item{last_column}{Specifies that the first column conditional formatting should be
applied.}

\item{no_hband}{Specifies that the first column conditional formatting should be applied.}

\item{no_vband}{Specifies that the first column conditional formatting should be applied.}

\item{width}{height in inches}

\item{height}{height in inches}

\item{res}{resolution of the png image in ppi}
}
\description{
This function add objects into a Word document. Values are added
as new paragraphs or tables.
}
\section{Methods (by class)}{
\itemize{
\item \code{character}: add a character vector.

\item \code{numeric}: add a numeric vector.

\item \code{factor}: add a factor vector.

\item \code{fpar}: add a \link{fpar} object. These objects enable
the creation of formatted paragraphs made of formatted chunks of text.

\item \code{data.frame}: add a data.frame object.

\item \code{block_caption}: add a \link{block_caption} object. These objects enable
the creation of set of formatted paragraphs made of formatted chunks of text.

\item \code{block_list}: add a \link{block_list} object.

\item \code{block_toc}: add a table of content (a \link{block_toc} object).

\item \code{external_img}: add an image (a \link{external_img} object).

\item \code{run_pagebreak}: add a \link{run_pagebreak} object.

\item \code{run_columnbreak}: add a \link{run_columnbreak} object.

\item \code{gg}: add a ggplot object.

\item \code{plot_instr}: add a base plot
}}

\examples{
doc <- read_docx()
doc <- body_add(doc, "A title", style = "heading 1")
doc <- body_add(doc, head(iris), style = "table_template")
doc <- body_add(doc, "Another title", style = "heading 1")
doc <- body_add(doc, letters, style = "Normal")
doc <- body_add(doc, "Table of content", style = "heading 1")
doc <- body_add(doc, block_toc())
print(doc, target = tempfile(fileext = ".docx"))
# print(doc, target = "test.docx")
}
